#### Supported colornames
C_black, C_white, C_red, C_lime, C_blue, C_yellow, C_aqua, C_fuchsia, C_silver, C_gray, C_maroon, C_olive, C_green, C_purple, C_teal, C_navy

---
#### Supported position's benchmarks
center, upper_left, upper_right, lower_left, lower_right, upper_center, left_center, lower_center, right_center

---
You could press **F12** to suspend/resume the program;
You could press **ESC** to quit the program;
You could press **WIN** to return to the desktop and leave the program running

---
`Simhei` is the default font. But if you put a "ttf" font file under expy package's path, then you can use the font (e.g. `drawText(text, font='consola'`)